Inschrijving | OiRA

Thema's

# Inschrijving

## Waarom moet ik mij inschrijven?

Bij aanvang van uw eerste risicobeoordeling wordt u gevraagd eerst een OiRA-account aan te maken - dit kan eenvoudig en snel.

Als u bent ingeschreven, kunt u op ieder gewenst moment inloggen om uw gegevens in te zien, verder te gaan met eerdere risicobeoordelingen of nieuwe risicobeoordelingen te beginnen.

Na inschrijving worden al uw sessies in het OiRA-systeem opgeslagen en zijn uw gegevens altijd beschikbaar.

In ons privacybeleid kunt u lezen hoe wij met uw persoonsgegevens omgaan.

## Wat is het verschil tussen inschrijven als gebruiker en een testsessie uitvoeren?

Belangstellenden kunnen in een testsessie zien hoe de tool werkt voordat zij een besluit nemen over inschrijving. Tijdens een testsessie worden uw gegevens niet opgeslagen, en u kunt de gegevens die u hebt ingevoerd, later niet meer opvragen. Tijdens een testsessie kunt u geen rapporten afdrukken maar wanneer u een OiRA-account hebt geopend, kunt u uw risicobeoordeling volledig documenteren.

## Een nieuwe account aanmaken

Is dit uw eerste bezoek? Volg deze eenvoudige stappen om te beginnen:

1.) Klik op “Inschrijven” om het inschrijvingsformulier te openen.

Inschrijvingsformulier.

2.) Vul uw e-mailadres in en kies een wachtwoord (tweemaal)

3.) Klik op “Volgende” om uw nieuwe account te registreren.

4.) Lees en aanvaard het privacybeleid voordat u verdergaat.

U bent nu ingelogd in het OiRA-systeem.

## Inloggen op een bestaande account

Als u zich al hebt ingeschreven, krijgt u als volgt toegang tot uw account:

1.) Ga naar het inlogformulier. Telkens als u toegang tot OiRA probeert te krijgen, verschijnt er een link naar het inlogformulier.

Inlogformulier.

2.) Vul uw e-mailadres en wachtwoord in.

3.) Log in door op de knop “Inloggen” te klikken.

Nadat u hebt ingelogd, ziet u onderstaand scherm. Vanaf dit scherm kunt u een nieuwe risicobeoordeling beginnen, of terugkeren naar eerder gestarte risicobeoordelingen.

Het dashboard.

Begin een nieuwe risicobeoordeling door de beoordeling een naam te geven (bv. Mijn-Onderneming 03-07-2018) of open een van uw eerdere risicobeoordelingen. Al uw risicobeoordelingen worden opgeslagen, zodat u deze altijd kunt raadplegen, tenzij u ervoor kiest risicobeoordelingen te verwijderen.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More